@@ -76,12 +76,12 @@ class Freebox(IPlugin):
 #[5, 7]
 						# search position '|' dans rs['idx']	
 						# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-					for rx in range int(rs['idx_sec']):
-						log.msg(" rx  :  %s" % (rx)
-						log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
-						log.msg("idx  :  %s" % (rs['idx']))
-						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
-						log.msg("resp  :  %s" % (resp))
+	##2				for rx in range int(rs['idx_sec']):
+	##2					log.msg(" rx  :  %s" % (rx)
+	##2					log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
+	##2					log.msg("idx  :  %s" % (rs['idx']))
+	##2					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
+	##2					log.msg("resp  :  %s" % (resp))
 				else:
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
